@@ -6,7 +6,7 @@ use Carp;
 use Data::Dump qw( dump );
 use Search::Query::Field::SWISH;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 __PACKAGE__->mk_accessors(
     qw(
@@ -66,14 +66,17 @@ sub init {
 
     #carp dump $self;
     $self->{wildcard} = '*';
-    if ( $self->parser->fields ) {
-        $self->{default_field} ||= $self->parser->default_field
-            || [ sort keys %{ $self->parser->fields } ];
-    }
-    else {
-        $self->{default_field} ||= $self->parser->default_field
-            || 'swishdefault';
+
+    $self->{default_field} ||= $self->parser->default_field
+        || 'swishdefault';
+
+    my $swishdefault_field;
+    eval { $swishdefault_field = $self->parser->get_field('swishdefault'); };
+    if ( !$swishdefault_field ) {
+        $self->parser->{fields}->{swishdefault}
+            = Search::Query::Field::SWISH->new( name => 'swishdefault' );
     }
+
     if ( $self->{default_field} and !ref( $self->{default_field} ) ) {
         $self->{default_field} = [ $self->{default_field} ];
     }
